<template>
  <div>
    <el-dialog :before-close="handleClose" :close-on-click-modal="false" :title="title"
               :visible.sync="isShowDialog" top="8vh" width="76%">
      <div class="bbsl-common-page">
        <div :class="['bbsl-table-search', isAdvanced ? 'advanced-search' : '']" class="bbsl-table-search">
          <el-form v-model="queryParam" label-width="auto">
            <el-row :gutter="10">

              <el-col :span="5">
                <el-form-item label="摄像机名称">
                  <el-input v-model="querys[0].value" clearable maxlength="64" placeholder="请输入摄像机名称"
                            size="medium"></el-input>
                  <!--                  <el-input v-model="querys[0].value" clearable placeholder="请输入摄像头名称" />-->
                </el-form-item>
              </el-col>
              <el-col :span="5">
                <el-form-item label="摄像机类型">
                  <el-select v-model="querys[1].value" clearable placeholder="请选择摄像机类型">
                    <el-option v-for="(item, index) in videoTypeList" :key="index"
                               :label="item.name" :value="item.value"></el-option>
                  </el-select>
                  <!--                  <el-select v-model="params.videoType" clearable placeholder="请选择摄像头类型">-->
                  <!--                    <el-option label="枪机" value="1"></el-option>-->
                  <!--                    <el-option label="球机" value="2"></el-option>-->
                  <!--                  </el-select>-->
                  <!--                  <el-input v-model="querys[1].value" clearable placeholder="请输入类型" />-->
                </el-form-item>
              </el-col>
              <el-col :span="5">
                <el-form-item label="摄像机状态">
                  <!--                <el-input v-model="querys[2].value" clearable placeholder="请输入状态" />-->
                  <el-select v-model="querys[2].value" clearable placeholder="请选择摄像机状态">
                    <el-option v-for="(item, index) in spdwztList" :key="index"
                               :label="item.name" :value="item.value"></el-option>
                  </el-select>
                </el-form-item>
              </el-col>
              <el-col :span="4">
                <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
                <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
              </el-col>
            </el-row>
          </el-form>
        </div>
        <div ref="contentPanel" class="bbsl-table-content">
          <div ref="btnPanel" class="bbsl-btn-content">
            <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
            <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
              <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                         style="margin-left: 10px"
                         type="danger">删除
              </el-button>
            </el-popconfirm>
          </div>
          <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }"
                    :data="tableData"
                    :header-cell-style="{ 'text-align': 'center' }"
                    :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                    size="mini" @row-dblclick="handleDbClick"
                    @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55"></el-table-column>
            <el-table-column label="序号" type="index" width="55"></el-table-column>
            <!--        <el-table-column label="受检单位名称" min-width="70" prop="targetYear" show-overflow-tooltip-->
            <!--                         sortable></el-table-column>-->
            <el-table-column label="摄像机名称" min-width="120" prop="videoName"
                             show-overflow-tooltip></el-table-column>
            <el-table-column label="摄像机编号" min-width="100" prop="videoCode"
                             show-overflow-tooltip></el-table-column>
            <el-table-column label="摄像机责任单位" min-width="80" prop="videoManagerCompanyName"
                             show-overflow-tooltip></el-table-column>
            <el-table-column
              :formatter="(row, column, cellValue) => videoTypeDict[cellValue]" label="摄像机类型"
              min-width="100" prop="videoType" show-overflow-tooltip></el-table-column>
            <el-table-column label="摄像机经度" min-width="60" prop="videoLgtd"
                             show-overflow-tooltip></el-table-column>
            <el-table-column label="摄像机纬度" min-width="60" prop="videoLttd" show-overflow-tooltip></el-table-column>
            <el-table-column label="摄像机状态" min-width="60" prop="videoStatus" show-overflow-tooltip>
              <template slot-scope="scope">
                                    <span :style="{
                                        color:
                                            scope.row.videoStatus == 1
                                                ? '#13ce66'
                                                : '',
                                        width: '100%',
                                    }">
                                        {{
                                        scope.row.videoStatus == 0
                                          ? '离线'
                                          : scope.row.videoStatus == 1
                                            ? '在线'
                                            : ''
                                      }}</span>
              </template>
            </el-table-column>
          </el-table>
          <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page"
                         :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                         :total="total" align="right"
                         background
                         class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                         @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
        </div>


      </div>
      <CmgtSaftygit
        ref="troubleshooting"
        :title="'计划'"
        @addDetail="addDetail"
      />
    </el-dialog>
  </div>
</template>
<script>
import {dictionaryEscape} from '@/utils/dictionary'
import {TableMixin} from '@/mixins/tableMixin'
import {ExtendParamsMixin} from '@/mixins/deviceExtend.js'
import resourceManage from '@/api/device/resourceManage.js'
import utils from '@/hotent-ui-util.js'
import API from '@/api/device/CamerDialog'
import CmgTSaftyHazardCheckManageDialog from '@/views/Manage/saftyPlan/components/CmgTSaftyHazardCheckManageDialog.vue'
import dictUtils from '@/components/dict/DictSelectUtils'
import CmgtSaftygit from '@/views/Manage/saftyPlan/CmgtSaftygit.vue'


export default {
  name: 'EquipmentManageModal',
  components: {CmgtSaftygit, CmgTSaftyHazardCheckManageDialog},
  mixins: [ExtendParamsMixin, TableMixin],
  data() {
    return {
      url: {
        delete: '/device/relationVideo/contract/'
      },
      videoTypeDict: {
        1: '枪机',
        2: '球机'
        // 根据实际情况添加更多映射
      },
      videoTypeList: [],
      spdwztList: [],
      // isShowAddDialog: false, // 控制新增弹层的显示
      isShowDialog: false,
      tableData: [],
      loading: false,
      queryParam: {},
      title: '新增',
      isSaved: false,
      activeCollapse1: '1',
      params: {
        videoType: '',
        videoName: '',
        videoStatus: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'r.name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'r.type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'r.status_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceId', // 如果 property 是必填字段，请填写正确的属性名
          relation: 'AND',
          value: '' // 将 deviceId 赋值给 value
        }
      ],
      queryBack: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'r.name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'r.type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'r.status_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceId', // 如果 property 是必填字段，请填写正确的属性名
          relation: 'AND',
          value: '' // 将 deviceId 赋值给 value
        }
      ]
    }
  },
  created() {
    this.videoTypeList = dictUtils.getDictItemsFromCache('sxtlx')
    this.spdwztList = dictUtils.getDictItemsFromCache('spdwzt')
  },
  mounted() {
  },
  methods: {
    handleOpen(deviceId) {
      this.deviceId = deviceId
      console.log(this.deviceId, '888')
      this.isShowDialog = true
      this.loadData()
    },
    handleAdd() {
      this.$refs.troubleshooting.add(this.deviceId)
      // this.$refs.camerDialog.handleOpen()
    },
    addDetail(list) {
      console.log('接收到的数据', list)
      this.loadData()
      // 将接收到的数据添加到表格中
      // this.tableData = [...this.tableData, ...list]
    },
    dictionaryEscape,

    add() {
      this.title = '新增'
      this.resetForm()
      // 清空 details 数组
      this.params.details = []
      this.params.id = null // 新增这一行
      // 重新初始化 details 数据
      const jjrpcYhlxList = dictUtils.getDictItemsFromCache('jjrpc_yhlx')
      if (jjrpcYhlxList && jjrpcYhlxList.length > 0) {
        this.params.details = jjrpcYhlxList.slice(0, 11).map(item => ({
          dictValue: item.value,
          name: item.name,
          indexValue: 0,
          remarks: '',
          sequence: item.sequence
        }))
      }
      this.showFormDia = true
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.querys[3].value = this.deviceId
      this.queryParam.querys = this.querys
      this.queryParam.params = this.params
      // this.queryParam.params = this.params
      // 添加 deviceId 查询条件
      // 动态构建查询条件
      // if (this.params.videoName) {
      //   this.querys[0].value = this.params.videoName // 摄像头名称
      //   this.queryParam.querys.push(this.querys[0])
      // }
      // if (this.params.videoType) {
      //   this.querys[1].value = this.params.videoType // 类型
      //   this.queryParam.querys.push(this.querys[1])
      // }
      // if (this.params.videoStatus) {
      //   this.querys[2].value = this.params.videoStatus // 状态
      //   this.queryParam.querys.push(this.querys[2])
      // }
      // this.queryParam.querys.push({
      //   group: 'main',
      //   operation: 'EQUAL',
      //   // parentGroup: 'deviceId',
      //   property: 'deviceId', // 如果 property 是必填字段，请填写正确的属性名
      //   relation: 'AND',
      //   value: this.deviceId // 将 deviceId 赋值给 value
      // })
      // if (this.querys[0].value) {
      //   this.queryParam.querys.push(this.querys[0])
      // }
      // if (this.querys[1].value) {
      //   this.queryParam.querys.push(this.querys[1])
      // }
      // if (this.querys[2].value) {
      //   this.queryParam.querys.push(this.querys[2])
      // }
      console.log('请求参数:', this.queryParam)
      API.camerList(this.queryParam, res => {
        console.log('响应数据', res)
        this.total = res.total
        this.tableData = res.rows
        this.loading = false
      })
    },
    handleDbClick() {
    },
    // handleDelete() {
    //   // 批量删除
    //   const ids = this.multipleSelection.join(',')
    //   const url = `${this.portal}${this.url.delete}?ids=${ids}`
    //   req.DELETE(url)
    //     .then(res => {
    //       this.$notify({
    //         type: 'success',
    //         message: '删除成功',
    //         duration: 2000
    //       })
    //       this.loadData()
    //       this.handleDeleteAfter && this.handleDeleteAfter()
    //     })
    //     .catch(error => {
    //       console.error('删除失败:', error)
    //       this.$message.error('删除失败，请稍后重试')
    //     })
    // },
    handleClose() {
      this.isShowDialog = false
      this.querys = JSON.parse(JSON.stringify(this.queryBack))
      this.params = {}
      this.productParams = []
      this.title = '新增'

      this.activeCollapse1 = '1'
    },
    handleSearch() {
      this.queryParam.pageBean.page = 1 // 重置为第一页
      this.loadData() // 调用 loadData 方法
    },
    handleSave() {
      this.isSaved = true
      this.handleExtendParams()
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          this.params.productId = this.params.productId.pop()
          let tempData = utils.deepClone(this.params)
          tempData = this.handleExtendSave(tempData)
          let method
          if (this.title === '新增') {
            method = resourceManage.addDevice
          }
          method(tempData, (response) => {
            if (response.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              this.handleClose()
              this.$parent.loadData(1)
            } else {
              this.$message.warning(response.message)
            }
          })
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000
          })
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

::v-deep .el-table {
  height: calc(100% - 80px);
}

::v-deep .el-table--scrollable-y .el-table__body-wrapper {
  height: calc(100% - 14.5%);
}

.bbsl-common-page {
  height: 60vh;
}

</style>
